@@ -342,9 +342,6 @@ int main(int argc, char *argv[])
             break;
 #ifdef KEY_RESIZE
         case KEY_RESIZE:
-# ifdef PDCURSES
-            resize_term(0, 0);
-# endif
             old_option = -1;
             erase();
             display_menu(old_option, new_option);
@@ -1641,7 +1638,7 @@ void remap(int tmarg, const short *colors)
                       orgcolors[i].blue);
 }
 
-void extended(int tmarg)
+static void show_color_cube( int tmarg)
 {
     short i, x, y, z, lmarg = (short)(COLS - 77) / 2;
 
@@ -1840,19 +1837,19 @@ void colorTest(WINDOW *win)
         "COLOR_CYAN", "COLOR_MAGENTA", "COLOR_YELLOW", "COLOR_WHITE"
     };
 
-    chtype fill = ACS_BLOCK;
-    bool widecol = (COLORS >= 16);
+    const bool widecol = (COLORS >= 16);
+    const chtype fill = widecol ? ' ' : '@';
+    const int tmarg = (LINES - 19) / 2;
+    const int col1 = (COLS - 60) / 2;
+    const int col2 = col1 + 20;
+    const int col3 = col2 + 20;
 
-    int i, j, tmarg, col1, col2, col3;
+    int i, j;
 
     INTENTIONALLY_UNUSED_PARAMETER( win);
     if (!has_colors())
         return;
 
-    tmarg = (LINES - 19) / 2;
-    col1 = (COLS - 60) / 2;
-    col2 = col1 + 20;
-    col3 = col2 + 20;
 
     attrset(A_BOLD);
     mvaddstr(tmarg, (COLS - 22) / 2, "Color Attribute Macros");
@@ -1871,9 +1868,13 @@ void colorTest(WINDOW *win)
 
     for (i = 0; i < 8; i++)
     {
-        init_pair((short)( i + 4), colors[i], COLOR_BLACK);
         if (widecol)
-            init_pair((short)( i + 12), (short)( colors[i] + 8), COLOR_BLACK);
+        {
+            init_pair(i + 4, COLOR_BLACK, colors[i]);
+            init_pair(i + 12, COLOR_BLACK, colors[i] + 8);
+        }
+        else
+            init_pair(i + 4, colors[i], COLOR_BLACK);
 
         mvaddstr(tmarg + i + 5, col1, colornames[i]);
 
@@ -1894,8 +1895,8 @@ void colorTest(WINDOW *win)
     if (can_change_color())
         remap(tmarg, colors);
 
-    if (COLORS >= 256)
-        extended(tmarg);
+    if( COLORS >= 256 && COLOR_PAIRS >= 256)
+        show_color_cube( tmarg);
 
 #if defined( __PDCURSESMOD__)
     if (can_change_color() && (long)COLORS == ((1L << 24) + 256L)
@@ -1903,7 +1904,7 @@ void colorTest(WINDOW *win)
         supergradient( tmarg);
 #endif
 
-    if (can_change_color() && COLORS >= 768)
+    if (can_change_color() && COLORS >= 768 && COLOR_PAIRS > 256)
         gradient(tmarg);
 }
 #endif
