@@ -8,7 +8,7 @@
 
 #include "curspriv.h"
 #include "pdcfb.h"
-#include "psf.h"
+#include "../common/psf.h"
 
 #ifdef PDC_WIDE
     #define USE_UNICODE_ACS_CHARS 1
@@ -18,78 +18,17 @@
 
 #include "../common/acs_defs.h"
 #include "../common/pdccolor.h"
+#include "../common/blink.c"
 
-/* Blinking of text and the cursor in this port has to be handled a
-little strangely.  "When possible",  we check to see if blink_interval
-milliseconds (currently set to 0.5 seconds) has elapsed since the
-blinking text was drawn.  If it has,  we flip the SP->blink_state
-bit and redraw all blinking text and the cursor.
+extern struct font_info PDC_font_info;
+extern struct video_info PDC_fb;
 
-Currently,  "when possible" is in PDC_napms( ) and in check_key( )
-(see vt/pdckbd.c for the latter).  This does mean that if you set up
-some blinking text,  and then do some processor-intensive stuff and
-aren't checking for keyboard input,  the text will stop blinking. */
-
-void PDC_check_for_blinking( void)
+static bool _is_fullwidth_glyph( const chtype c)
 {
-   static long prev_time = 0;
-   const long t = PDC_millisecs( );
-   const long blink_interval = 500L;
+   const int unicode_point = (int)( c & A_CHARTEXT) | 0x200000;
+   const int glyph_idx = find_psf_or_vgafont_glyph( &PDC_font_info, unicode_point);
 
-   if( !t || t - prev_time > blink_interval)
-   {
-      int x1, y, x2;
-
-      prev_time = t;
-      SP->blink_state ^= 1;
-      for( y = 0; y < SP->lines; y++)
-      {
-         chtype *c = curscr->_y[y];
-
-         for( x1 = 0; x1 < SP->cols; x1++)
-            if( c[x1] & A_BLINK)
-            {
-               x2 = x1 + 1;
-               while( x2 < SP->cols && (c[x2] & A_BLINK) && x2 - x1 < MAX_PACKET_LEN - 1)
-                  x2++;
-               PDC_transform_line( y, x1, x2 - x1, c + x1);
-               x1 = x2;
-            }
-         if( SP->visibility && y == SP->cursrow)
-            PDC_transform_line( y, SP->curscol, 1, c + SP->curscol);
-      }
-   }
-}
-
-void PDC_gotoyx( int row, int col)
-{
-    PDC_LOG(("PDC_gotoyx() - called: row %d col %d from row %d col %d\n",
-             row, col, SP->cursrow, SP->curscol));
-
-    if( !SP || !curscr)
-         return;
-
-                /* clear the old cursor,  if it's on-screen: */
-    if( SP->cursrow >= 0 && SP->curscol >= 0
-         && SP->cursrow < SP->lines && SP->curscol < SP->cols
-         && (SP->cursrow != row || SP->curscol != col))
-    {
-        const int temp_visibility = SP->visibility;
-
-        SP->visibility = 0;
-        PDC_transform_line( SP->cursrow, SP->curscol, 1,
-                           curscr->_y[SP->cursrow] + SP->curscol);
-        SP->visibility = temp_visibility;
-    }
-
-               /* ...then draw the new  */
-    if( row >= 0 && col >= 0
-         && row < SP->lines && col < SP->cols)
-    {
-        SP->cursrow = row;
-        SP->curscol = col;
-        PDC_transform_line( row, col, 1, curscr->_y[row] + col);
-    }
+   return( glyph_idx >= 0 && glyph_idx < (int)PDC_font_info.n_glyphs);
 }
 
 static const uint8_t *_get_raw_glyph_bytes( struct font_info *font, int unicode_point)
@@ -104,9 +43,6 @@ static const uint8_t *_get_raw_glyph_bytes( struct font_info *font, int unicode_
     return( font->glyphs + glyph_idx * font_char_size_in_bytes * font->height);
 }
 
-extern struct font_info PDC_font_info;
-extern struct video_info PDC_fb;
-
 void PDC_draw_rectangle( const int xpix, const int ypix,
                   const int xsize, const int ysize, const uint32_t color)
 {
@@ -143,12 +79,8 @@ static void _add_combining_character_glyph( uint8_t *glyph, const int code_point
 
 extern int PDC_orientation;
 
-#define LINE_ATTRIBS (WA_UNDERLINE | WA_TOP | WA_LEFT | WA_RIGHT | WA_STRIKEOUT)
-
-#define LOC_UNDERLINE      1
-#define LOC_RIGHT          2
-#define LOC_TOP            4
-#define LOC_LEFT           8
+#define SIDE_LINE_ATTRIBS (A_UNDERLINE | A_TOP | A_LEFT | A_RIGHT)
+#define LINE_ATTRIBS (SIDE_LINE_ATTRIBS | A_STRIKEOUT)
 
 /* Usually,  we can just return a pointer to the glyph data from
 the PSF file (using _get_raw_glyph_bytes()).  If the glyph has to
@@ -156,6 +88,8 @@ be modified for line drawings or a cursor,  or it's a combined
 character,  or it's bold or italic,  we build the glyph in the
 scratch space and return 'scratch' instead.  */
 
+static int fullwidth_offset;
+
 static const uint8_t *_get_glyph( const chtype ch, const int cursor_type,
                                  uint8_t *scratch)
 {
@@ -179,7 +113,7 @@ static const uint8_t *_get_glyph( const chtype ch, const int cursor_type,
         c = (int)acs_map[c & 0x7f];
     else if( c < (int)' ' || (c >= 0x80 && c <= 0x9f))
         c = ' ';
-    rval = _get_raw_glyph_bytes( &PDC_font_info, c);
+    rval = _get_raw_glyph_bytes( &PDC_font_info, c | fullwidth_offset);
 #ifdef USING_COMBINING_CHARACTER_SCHEME
     if( cursor_type || (ch & (LINE_ATTRIBS | A_BOLD | A_ITALIC)) || root)
 #else
@@ -187,7 +121,7 @@ static const uint8_t *_get_glyph( const chtype ch, const int cursor_type,
 #endif
     {
         const int font_char_size_in_bytes = (PDC_font_info.width + 7) >> 3;
-        int i, line_mask;
+        int i;
 
         memcpy( scratch, rval, PDC_font_info.charsize);
         rval = (const uint8_t *)scratch;
@@ -214,18 +148,13 @@ static const uint8_t *_get_glyph( const chtype ch, const int cursor_type,
             _add_combining_character_glyph( scratch, (int)newchar);
         }
 #endif
-        if( cursor_type > 0 && cursor_type < 8)
+        if( cursor_type == 1 || cursor_type >= 5)
         {
             const int cursors[8] = { 0, '_', FULL_BLOCK, 0,   /*outlined block */
-                           LEFT_HALF_BLOCK, LOWER_HALF_BLOCK, 0, '+' };
+                           LEFT_HALF_BLOCK, LOWER_HALF_BLOCK, CENTERED_SQUARE, '+' };
 
             _add_combining_character_glyph( scratch, cursors[cursor_type]);
         }
-        line_mask = (ch & WA_UNDERLINE ? LOC_UNDERLINE : 0)
-                           | (ch & WA_LEFT ? LOC_LEFT : 0)
-                           | (ch & WA_TOP ? LOC_TOP : 0)
-                           | (ch & WA_RIGHT ? LOC_RIGHT : 0);
-        line_mask = (line_mask >> PDC_orientation) | (line_mask << (4 - PDC_orientation));
         if( ch & WA_STRIKEOUT)
         {
             if( PDC_orientation & 1)   /* rotated left or right */
@@ -240,15 +169,15 @@ static const uint8_t *_get_glyph( const chtype ch, const int cursor_type,
                 memset( scratch + (PDC_font_info.height / 2) * font_char_size_in_bytes,
                         0xff, font_char_size_in_bytes);
         }
-        if( line_mask & LOC_TOP)
+        if( ch & WA_TOP)
             memset( scratch, 0xff, font_char_size_in_bytes);
-        if( line_mask & LOC_UNDERLINE)
+        if( ch & WA_UNDERLINE)
             memset( scratch + (PDC_font_info.height - 1) * font_char_size_in_bytes,
                         0xff, font_char_size_in_bytes);
-        if( line_mask & LOC_LEFT)
+        if( ch & WA_LEFT)
             for( i = 0; i < (int)PDC_font_info.height; i++)
                scratch[i * font_char_size_in_bytes] |= 0x80;
-        if( line_mask & LOC_RIGHT)
+        if( ch & WA_RIGHT)
         {
             scratch += font_char_size_in_bytes - 1;
             for( i = 0; i < (int)PDC_font_info.height; i++)
@@ -258,6 +187,23 @@ static const uint8_t *_get_glyph( const chtype ch, const int cursor_type,
     return( rval);
 }
 
+static const uint8_t *_get_rotated_glyph( chtype ch, const int cursor_type,
+                                 uint8_t *scratch)
+{
+   if( PDC_orientation && (ch & SIDE_LINE_ATTRIBS))
+      {
+      chtype new_ch = ch & ~SIDE_LINE_ATTRIBS;
+      size_t i;
+      const chtype masks[4] = { A_TOP, A_RIGHT, A_UNDERLINE, A_LEFT};
+
+      for( i = 0; i < 4; i++)
+         if( ch & masks[i])
+            new_ch |= masks[(i + PDC_orientation) & 3];
+      ch = new_ch;
+      }
+   return( _get_glyph( ch, cursor_type, scratch));
+}
+
 #ifdef HAVE_MOUSE
 
 int PDC_mouse_x = 317, PDC_mouse_y = 131;
@@ -281,7 +227,6 @@ const unsigned char cursor_data[117] = { 19, 1, 1,
 
 static void _draw_pixel( int xpix, int ypix, const int black)
 {
-    extern int PDC_orientation;
     const int line_len = PDC_fb.line_length * 8 / PDC_fb.bits_per_pixel;
     int tval;
     long video_offset;
@@ -351,7 +296,7 @@ bool PDC_remove_mouse_cursor( void)
    assert( right >= left);
    while( y <= bottom && y < SP->lines && right >= left)
       {
-      PDC_transform_line( y, left, right - left + 1, curscr->_y[y] + left);
+      PDC_transform_line_sliced( y, left, right - left + 1, curscr->_y[y] + left);
       y++;
       }
    _mouse_cursor_shown = TRUE;
@@ -405,9 +350,10 @@ order from what the other platforms expect : */
 void PDC_transform_line(int lineno, int x, int len, const chtype *srcp)
 {
     const int font_char_size_in_bytes = (PDC_font_info.width + 7) >> 3;
-    int cursor_to_draw = 0;
     const int line_len = PDC_fb.line_length * 8 / PDC_fb.bits_per_pixel;
     uint8_t scratch[300];
+    bool is_fullwidth = FALSE;
+    chtype cursor_ch;
 #ifdef HAVE_MOUSE
     const int t_width = _orig_font_width( );
     const int left = x * t_width, right = (x + len) * t_width;
@@ -419,21 +365,24 @@ void PDC_transform_line(int lineno, int x, int len, const chtype *srcp)
     assert( lineno >= 0);
     assert( lineno < SP->lines);
     assert( len > 0);
-    if( lineno == SP->cursrow && x <= SP->curscol && x + len > SP->curscol)
-    {
-        cursor_to_draw = (SP->blink_state ? SP->visibility & 0xff : (SP->visibility >> 8));
-        if( cursor_to_draw)   /* if there's a cursor appearing in this run of text... */
-        {
-            if( x < SP->curscol)  /* ...draw the part _before_ the cursor (if any)... */
-                PDC_transform_line( lineno, x, SP->curscol - x, srcp);
-            len -= SP->curscol - x;
-            srcp += SP->curscol - x;
-            x = SP->curscol;
-            if( len > 1)          /* ...then the part _after the cursor (if any)... */
-                PDC_transform_line( lineno, x + 1, len - 1, srcp + 1);
-            len = 1;    /* ... then fall through and just draw the cell with the cursor */
-        }
+    fullwidth_offset = 0;
+    if( SP->drawing_cursor >= 2 && SP->drawing_cursor <= 4)
+    {           /* blink full cell, outlined box, or caret */
+        const chtype flags[3] = { A_REVERSE, SIDE_LINE_ATTRIBS, A_LEFT };
+
+        cursor_ch = *srcp ^ flags[SP->drawing_cursor - 2];
+        srcp = &cursor_ch;
     }
+    if( x + len < SP->cols)     /* check for fullwidth character at end */
+      if( _is_fullwidth_glyph( srcp[len - 1]))
+         {
+         if( len > 1)
+            PDC_transform_line( lineno, x, len - 1, srcp);
+         x += len - 1;
+         srcp += len - 1;
+         len = 2;
+         is_fullwidth = TRUE;
+         }
     while( len)
     {
         int run_len = 0, x1, y1;
@@ -491,7 +440,7 @@ void PDC_transform_line(int lineno, int x, int len, const chtype *srcp)
             x += run_len;
             while( run_len--)
             {
-                const uint8_t *fontptr = _get_glyph( *srcp, cursor_to_draw, scratch);
+                const uint8_t *fontptr = _get_rotated_glyph( *srcp, SP->drawing_cursor, scratch);
                 uint32_t *fb_ptr = tptr;
                 int i, j;
 
@@ -502,13 +451,15 @@ void PDC_transform_line(int lineno, int x, int len, const chtype *srcp)
                     fb_ptr += line_len - PDC_font_info.width;
                     fontptr += font_char_size_in_bytes;
                 }
-                srcp++;
+                if( !is_fullwidth)
+                   srcp++;
+                else
+                    fullwidth_offset = 0x200000;
                 tptr += next_glyph;
             }
         }
         if( PDC_fb.bits_per_pixel == 8)
         {
-            const int line_len = PDC_fb.line_length; /* / sizeof( uint8_t); */
             int i, integer_fg_idx, integer_bg_idx;
             uint8_t fg_idx, bg_idx;
             uint8_t *tptr = (uint8_t *)PDC_fb.framebuf + video_offset;
@@ -537,18 +488,21 @@ void PDC_transform_line(int lineno, int x, int len, const chtype *srcp)
             bg_idx = (uint8_t)integer_bg_idx;
             for( i = 0; i < run_len; i++)
             {
-                const uint8_t *fontptr = _get_glyph( *srcp, cursor_to_draw, scratch);
+                const uint8_t *fontptr = _get_rotated_glyph( *srcp, SP->drawing_cursor, scratch);
                 uint8_t *fb_ptr = tptr;
-                int i, j;
+                int k, j;
 
-                for( i = 0; i < (int)PDC_font_info.height; i++)
+                for( k = 0; k < (int)PDC_font_info.height; k++)
                 {
                     for( j = 0; j < (int)PDC_font_info.width; j++)
                         *fb_ptr++ = ((fontptr[j >> 3] << (j & 7)) & 0x80) ? fg_idx : bg_idx;
-                    fb_ptr += line_len - PDC_font_info.width;
+                    fb_ptr += PDC_fb.line_length - PDC_font_info.width;
                     fontptr += font_char_size_in_bytes;
                 }
-                srcp++;
+                if( !is_fullwidth)
+                   srcp++;
+                else
+                    fullwidth_offset = 0x200000;
                 len--;
                 tptr += next_glyph;
                 x++;
