@@ -244,7 +244,7 @@ int start_color(void)
                         SP->default_background_idx);
     if( !SP->_preserve)
         curscr->_clear = TRUE;
-#if !defined( CHTYPE_32) && !defined(OS2) && !defined(DOS)
+#if !defined( CHTYPE_32) && !defined( CHTYPE_16) && !defined(OS2) && !defined(DOS)
     if( COLORS >= 1024 && (long)INT_MAX > 1024L * 1024L)
         COLOR_PAIRS = 1024 * 1024;
     else if( COLORS >= 16)
