@@ -506,8 +506,6 @@ int PDC_get_key(void)
     case SDL_TEXTINPUT:
         PDC_mouse_set();
         return _process_key_event();
-    case SDL_USEREVENT:
-        PDC_blink_text();
     }
 
     return -1;
