@@ -387,11 +387,51 @@ static int _modifier_key( KeySym *key)
 }
 #endif
 
+static int _is_maximized( void)
+{
+    const Atom wmState = XInternAtom(dis, "_NET_WM_STATE", True);
+    const Atom max_vert = XInternAtom(dis, "_NET_WM_STATE_MAXIMIZED_VERT", True);
+    const Atom max_horz = XInternAtom(dis, "_NET_WM_STATE_MAXIMIZED_HORZ", True);
+    Atom type;
+    int format, rval = 0;
+    unsigned long nItem, bytesAfter, i;
+    unsigned char *properties = NULL;
+
+    XGetWindowProperty(dis, win, wmState, 0, (~0L), False, AnyPropertyType,
+                       &type, &format, &nItem, &bytesAfter, &properties);
+    assert( properties);
+    for( i = 0; i < nItem; i++)
+        if( ((long *)properties)[i] == (long)max_vert)
+            rval |= 1;
+        else if( ((long *)properties)[i] == (long)max_horz)
+            rval |= 2;
+    XFree( properties);
+    return( rval);
+}
+
+static void _check_for_resize( void)
+{
+   bool resize_not_in_queue = TRUE;
+   int i;
+
+   for( i = queue_low; i != queue_high; i = (i + 1) % QUEUE_SIZE)
+      if( key_queue[i] == KEY_RESIZE)
+         resize_not_in_queue = FALSE;
+   if( resize_not_in_queue)
+      {
+      SP->resized = TRUE;
+      add_to_queue( KEY_RESIZE);
+      }
+}
+
+int PDC_look_for_font( const int step);      /* pdcscrn.c */
+
 static bool check_key( int *c)
 {
+   static XEvent prev_report;
    XEvent report;
-   bool rval = false;
-   bool wait_for_more_mouse = false;
+   bool rval = FALSE;
+   bool wait_for_more_mouse = FALSE;
 
 #ifndef NO_LEAKS
    if( !_xim)
@@ -419,18 +459,8 @@ static bool check_key( int *c)
             new_rows = attrib.height / PDC_font_height;
             if( new_cols != PDC_cols || new_rows != PDC_rows)
                {
-               bool resize_not_in_queue = true;
-               int i;
-
                PDC_resize_screen( new_rows, new_cols);
-               for( i = queue_low; i != queue_high; i = (i + 1) % QUEUE_SIZE)
-                  if( key_queue[i] == KEY_RESIZE)
-                     resize_not_in_queue = false;
-               if( resize_not_in_queue)
-                  {
-                  SP->resized = TRUE;
-                  add_to_queue( KEY_RESIZE);
-                  }
+               _check_for_resize( );
                }
             else
                {
@@ -505,6 +535,25 @@ static bool check_key( int *c)
                       key = key_table[i].normal;
                   key_to_add = (int)key;
                   }
+            if( report.xkey.state & ControlMask)
+               if( key_to_add == '-' || key_to_add == '+')
+                  {
+                  if( PDC_look_for_font( (key_to_add == '+') ? 1 : -1))
+                     {
+                     if( _is_maximized( ))
+                        {
+                        XWindowAttributes attrib;
+
+                        XGetWindowAttributes( dis, win, &attrib);
+                        PDC_resize_screen( attrib.height / PDC_font_height,
+                                           attrib.width / PDC_font_width);
+                        _check_for_resize( );
+                        }
+                     else
+                        PDC_resize_screen( PDC_rows, PDC_cols);
+                     }
+                  key_to_add = -1;     /* suppress it */
+                  }
             if( key_to_add > -1)
                {
                if( key_to_add == PDC_get_function_key( FUNCTION_KEY_ABORT)
@@ -512,6 +561,11 @@ static bool check_key( int *c)
                   raise( SIGINT);
                add_to_queue( key_to_add);
                SP->key_modifiers = 0;
+               if( prev_report.xkey.type == KeyRelease
+                      && report.xkey.time == prev_report.xkey.time
+                      && report.xkey.keycode == prev_report.xkey.keycode)
+                   SP->key_modifiers |= PDC_KEY_MODIFIER_REPEAT;
+
                if( report.xkey.state & Mod2Mask)
                    SP->key_modifiers |= PDC_KEY_MODIFIER_NUMLOCK;
 
@@ -580,6 +634,7 @@ static bool check_key( int *c)
          default:
             break;
          }
+      prev_report = report;
       if( wait_for_more_mouse)   /* wait for a possible press or release event */
          {
          const long t_end = PDC_millisecs( ) + SP->mouse_wait;
